@@ -12,10 +12,12 @@
 package Error;
 
 use strict;
+use warnings;
+
 use vars qw($VERSION);
 use 5.004;
 
-$VERSION = "0.17019"; 
+$VERSION = "0.17022";
 
 use overload (
 	'""'	   =>	'stringify',
@@ -49,8 +51,8 @@ sub import {
     shift;
     my @tags = @_;
     local $Exporter::ExportLevel = $Exporter::ExportLevel + 1;
-    
-    @tags = grep { 
+
+    @tags = grep {
        if( $_ eq ':warndie' ) {
           Error::WarnDie->import();
           0;
@@ -91,17 +93,17 @@ sub prior {
 
 sub flush {
     shift; #ignore
-    
+
     unless (@_) {
        $LAST = undef;
        return;
     }
-    
+
     my $pkg = shift;
     return unless ref($pkg);
-   
-    undef $ERROR{$pkg} if defined $ERROR{$pkg}; 
-} 
+
+    undef $ERROR{$pkg} if defined $ERROR{$pkg};
+}
 
 # Return as much information as possible about where the error
 # happened. The -stacktrace element only exists if $Error::DEBUG
@@ -180,7 +182,7 @@ sub throw {
 
     # if we are not rethrow-ing then create the object to throw
     $self = $self->new(@_) unless ref($self);
-    
+
     die $Error::THROWN = $self;
 }
 
@@ -259,7 +261,7 @@ package Error::Simple;
 
 use vars qw($VERSION);
 
-$VERSION = "0.17019";
+$VERSION = "0.17022";
 
 @Error::Simple::ISA = qw(Error);
 
@@ -385,7 +387,7 @@ sub run_clauses ($$$\@) {
 	    else {
 		$err = $@ || $Error::THROWN;
 
-		$err = $Error::ObjectifyCallback->({'text' =>$err}) 
+		$err = $Error::ObjectifyCallback->({'text' =>$err})
 			unless ref($err);
 	    }
 	}
@@ -479,7 +481,7 @@ sub except (&;$) {
     my $code = shift;
     my $clauses = shift || {};
     my $catch = $clauses->{'catch'} ||= [];
-    
+
     my $sub = sub {
 	my $ref;
 	my(@array) = $code->($_[0]);
@@ -620,7 +622,7 @@ Error - Error/exception handling in an OO-ish way
 =head1 WARNING
 
 Using the "Error" module is B<no longer recommended> due to the black-magical
-nature of its syntactic sugar, which often tends to break. Its maintainers 
+nature of its syntactic sugar, which often tends to break. Its maintainers
 have stopped actively writing code that uses it, and discourage people
 from doing so. See the "SEE ALSO" section below for better recommendations.
 
@@ -635,7 +637,7 @@ from doing so. See the "SEE ALSO" section below for better recommendations.
 	record Error::Simple("A simple error")
 	    and return;
     }
- 
+
     unlink($file) or throw Error::Simple("$file: $!",$!);
 
     try {
@@ -903,7 +905,7 @@ is a numeric value. These values are what will be returned by the
 overload methods.
 
 If the text value ends with C<at file line 1> as $@ strings do, then
-this infomation will be used to set the C<-file> and C<-line> arguments
+this information will be used to set the C<-file> and C<-line> arguments
 of the error object.
 
 This class is used internally if an eval'd block die's with an error
@@ -914,9 +916,9 @@ that is a plain string. (Unless C<$Error::ObjectifyCallback> is modified)
 
 This variable holds a reference to a subroutine that converts errors that
 are plain strings to objects. It is used by Error.pm to convert textual
-errors to objects, and can be overrided by the user.
+errors to objects, and can be overridden by the user.
 
-It accepts a single argument which is a hash reference to named parameters. 
+It accepts a single argument which is a hash reference to named parameters.
 Currently the only named parameter passed is C<'text'> which is the text
 of the error, but others may be available in the future.
 
@@ -1004,7 +1006,7 @@ on what you want. (Because Error's syntactic sugar tends to break.)
 L<Error::Exception> aims to combine L<Error> and L<Exception::Class>
 "with correct stringification".
 
-L<TryCatch> and L<Try::Tiny> are similar in concept to Error.pm only providing 
+L<TryCatch> and L<Try::Tiny> are similar in concept to Error.pm only providing
 a syntax that hopefully breaks less.
 
 =head1 KNOWN BUGS
